# Fact Sheet Order and Colors
### On this page
  * [Fact Sheet Order and Colors in the Meta Model v4](https://help.sap.com/docs/leanix/ea/fact-sheet-order-and-colors#fact-sheet-order-and-colors-in-the-meta-model-v4)
  * [Reordering Fact Sheets](https://help.sap.com/docs/leanix/ea/fact-sheet-order-and-colors#reordering-fact-sheets)
  * [Changing the Fact Sheet Color](https://help.sap.com/docs/leanix/ea/fact-sheet-order-and-colors#changing-the-fact-sheet-color)


Get an overview of standard order and colors of fact sheets in the meta model v4 and learn how to change them.
